aboutsummaryrefslogtreecommitdiff
path: root/lib/csapi/notifications.h
diff options
context:
space:
mode:
authorAndres Salomon <dilinger@queued.net>2021-01-18 04:00:14 -0500
committerAndres Salomon <dilinger@queued.net>2021-01-18 04:00:14 -0500
commit09eb39236666e81d5da014acea011dcd74d0999b (patch)
tree52876d96be71be1a39d5d935c1295a51995e8949 /lib/csapi/notifications.h
parentf1788ee27f33e9339334e0d79bde9a27d9ce2e44 (diff)
parenta4e78956f105875625b572d8b98459ffa86fafe5 (diff)
downloadlibquotient-09eb39236666e81d5da014acea011dcd74d0999b.tar.gz
libquotient-09eb39236666e81d5da014acea011dcd74d0999b.zip
Update upstream source from tag 'upstream/0.6.4'
Update to upstream version '0.6.4' with Debian dir aa8705fd74743e79c043bc9e3e425d5064404cfe
Diffstat (limited to 'lib/csapi/notifications.h')
-rw-r--r--lib/csapi/notifications.h146
1 files changed, 77 insertions, 69 deletions
diff --git a/lib/csapi/notifications.h b/lib/csapi/notifications.h
index 898b5154..ff499c7a 100644
--- a/lib/csapi/notifications.h
+++ b/lib/csapi/notifications.h
@@ -4,86 +4,94 @@
#pragma once
+#include "events/eventloader.h"
#include "jobs/basejob.h"
-#include "events/eventloader.h"
-#include "converters.h"
-#include <QtCore/QVector>
-#include <QtCore/QVariant>
-#include <QtCore/QJsonObject>
+namespace Quotient {
-namespace QMatrixClient
-{
- // Operations
+/*! \brief Gets a list of events that the user has been notified about
+ *
+ * This API is used to paginate through the list of events that the
+ * user has been, or would have been notified about.
+ */
+class GetNotificationsJob : public BaseJob {
+public:
+ // Inner data structures
- /// Gets a list of events that the user has been notified about
- ///
/// This API is used to paginate through the list of events that the
/// user has been, or would have been notified about.
- class GetNotificationsJob : public BaseJob
- {
- public:
- // Inner data structures
-
- /// This API is used to paginate through the list of events that the
- /// user has been, or would have been notified about.
- struct Notification
- {
- /// The action(s) to perform when the conditions for this rule are met.
- /// See `Push Rules: API`_.
- QVector<QVariant> actions;
- /// The Event object for the event that triggered the notification.
- EventPtr event;
- /// The profile tag of the rule that matched this event.
- QString profileTag;
- /// Indicates whether the user has sent a read receipt indicating
- /// that they have read this message.
- bool read;
- /// The ID of the room in which the event was posted.
- QString roomId;
- /// The unix timestamp at which the event notification was sent,
- /// in milliseconds.
- int ts;
- };
+ struct Notification {
+ /// The action(s) to perform when the conditions for this rule are met.
+ /// See `Push Rules: API`_.
+ QVector<QVariant> actions;
+ /// The Event object for the event that triggered the notification.
+ EventPtr event;
+ /// The profile tag of the rule that matched this event.
+ QString profileTag;
+ /// Indicates whether the user has sent a read receipt indicating
+ /// that they have read this message.
+ bool read;
+ /// The ID of the room in which the event was posted.
+ QString roomId;
+ /// The unix timestamp at which the event notification was sent,
+ /// in milliseconds.
+ int ts;
+ };
- // Construction/destruction
+ // Construction/destruction
- /*! Gets a list of events that the user has been notified about
- * \param from
- * Pagination token given to retrieve the next set of events.
- * \param limit
- * Limit on the number of events to return in this request.
- * \param only
- * Allows basic filtering of events returned. Supply ``highlight``
- * to return only events where the notification had the highlight
- * tweak set.
- */
- explicit GetNotificationsJob(const QString& from = {}, Omittable<int> limit = none, const QString& only = {});
+ /*! \brief Gets a list of events that the user has been notified about
+ *
+ * \param from
+ * Pagination token given to retrieve the next set of events.
+ *
+ * \param limit
+ * Limit on the number of events to return in this request.
+ *
+ * \param only
+ * Allows basic filtering of events returned. Supply ``highlight``
+ * to return only events where the notification had the highlight
+ * tweak set.
+ */
+ explicit GetNotificationsJob(const QString& from = {},
+ Omittable<int> limit = none,
+ const QString& only = {});
- /*! Construct a URL without creating a full-fledged job object
- *
- * This function can be used when a URL for
- * GetNotificationsJob is necessary but the job
- * itself isn't.
- */
- static QUrl makeRequestUrl(QUrl baseUrl, const QString& from = {}, Omittable<int> limit = none, const QString& only = {});
+ /*! \brief Construct a URL without creating a full-fledged job object
+ *
+ * This function can be used when a URL for GetNotificationsJob
+ * is necessary but the job itself isn't.
+ */
+ static QUrl makeRequestUrl(QUrl baseUrl, const QString& from = {},
+ Omittable<int> limit = none,
+ const QString& only = {});
- ~GetNotificationsJob() override;
+ // Result properties
- // Result properties
+ /// The token to supply in the ``from`` param of the next
+ /// ``/notifications`` request in order to request more
+ /// events. If this is absent, there are no more results.
+ QString nextToken() const { return loadFromJson<QString>("next_token"_ls); }
- /// The token to supply in the ``from`` param of the next
- /// ``/notifications`` request in order to request more
- /// events. If this is absent, there are no more results.
- const QString& nextToken() const;
- /// The list of events that triggered notifications.
- std::vector<Notification>&& notifications();
+ /// The list of events that triggered notifications.
+ std::vector<Notification> notifications()
+ {
+ return takeFromJson<std::vector<Notification>>("notifications"_ls);
+ }
+};
- protected:
- Status parseJson(const QJsonDocument& data) override;
+template <>
+struct JsonObjectConverter<GetNotificationsJob::Notification> {
+ static void fillFrom(const QJsonObject& jo,
+ GetNotificationsJob::Notification& result)
+ {
+ fromJson(jo.value("actions"_ls), result.actions);
+ fromJson(jo.value("event"_ls), result.event);
+ fromJson(jo.value("profile_tag"_ls), result.profileTag);
+ fromJson(jo.value("read"_ls), result.read);
+ fromJson(jo.value("room_id"_ls), result.roomId);
+ fromJson(jo.value("ts"_ls), result.ts);
+ }
+};
- private:
- class Private;
- QScopedPointer<Private> d;
- };
-} // namespace QMatrixClient
+} // namespace Quotient